% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/be_acworth.R
\name{be_acworth_eq_4}
\alias{be_acworth_eq_4}
\title{be_acworth_eq_4}
\usage{
be_acworth_eq_4(s2_gw, s2_et, s2_at, m2_gw, m2_et, d_phase,
  inverse = TRUE)
}
\arguments{
\item{s2_gw}{\code{numeric} s2 component in the groundwater levels}

\item{s2_et}{\code{numeric} s2 component in the earth tides}

\item{s2_at}{\code{numeric} s2 component for atmospheric pressure}

\item{m2_gw}{\code{numeric} m2 component in the groundwater levels}

\item{m2_et}{\code{numeric} m2 component in the earth tides}

\item{d_phase}{\code{numeric} phase difference between Earth tide and atmospheric drivers s2_et and s2_at}

\item{inverse}{\code{logical} whether the barometric relationship is inverse (TRUE means that when the barometric pressure goes up the measured water level goes down (vented transducer, depth to water), FALSE means that when the barometric pressure goes up so does the measured pressure (non-vented transducer))}
}
\value{
barometric efficiency
}
\description{
Implementation of Acworth et. al. 2016 equation 4.
}
\examples{

be_acworth_eq_4(s2_at = 7.461,
           s2_et=224.640,
           s2_gw=4.086,
           m2_gw = 0.471,
           m2_et = 492.526,
           d_phase=-56.709)
be_acworth_eq_4(s2_at = 6.164,
           s2_et=270.463,
           s2_gw=0.329,
           m2_gw = 0.225,
           m2_et = 551.572,
           d_phase=-71.726)
be_acworth_eq_4(s2_at = 5.897,
           s2_et=234.478,
           s2_gw=5.536,
           m2_gw = 0.773,
           m2_et = 558.075,
           d_phase=-70.393)

}
\references{
Acworth, R. I., Halloran, L. J. S., Rau, G. C., Cuthbert, M. O., & Bernardi, T. L. (2016). An objective frequency-domain method for quantifying confined aquifer compressible storage using Earth and atmospheric tides. Geophysical Research Letters, 43 (November). \doi{https://doi.org/10.1002/2016GL071328}
}
