% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/be_clark.R
\name{be_clark}
\alias{be_clark}
\title{be_clark}
\usage{
be_clark(dat, dep = "wl", ind = "baro", lag_space = 1,
  inverse = TRUE, return_model = FALSE)
}
\arguments{
\item{dat}{data that has the independent and dependent variables (data.table)}

\item{dep}{name of the dependent variable column (character).  This is 
typically the name for the column holding your water level data.}

\item{ind}{name of the independent variable column (character).  This is 
typically the name for the column holding your barometric pressure data.}

\item{lag_space}{space between difference calculation in number of observations}

\item{inverse}{whether the barometric relationship is inverse
(TRUE means that when the barometric pressure goes up the measured water
level goes down (vented transducer, depth to water), FALSE means that when 
the barometric pressure goes up so does the measured pressure 
(non-vented transducer)) (logical).}

\item{return_model}{whether to return the lm model or just the barometric/loading
efficiency (logical).#'}
}
\value{
\code{lm} linear model for Clark's method.  The coefficient is the BE/LE
}
\description{
Clark 1967 solution for calculating barometric efficiency.
}
\examples{
library(data.table)
datetime <- seq.POSIXt(as.POSIXct("2016-01-01 12:00:00"),
                       as.POSIXct("2016-01-05 12:00:00"), by='sec' )
baro <- sin(seq(0, 2*pi, length.out = length(datetime)))
wl   <- -0.4 * baro + rnorm(length(datetime), sd = 0.02)
dat  <- data.table(baro, wl, datetime)
be_clark(dat, dep='wl', ind='baro', lag_space=1, inverse=TRUE)

}
\references{
Clark, W., 1967. Computing the Barometric Efficiency of a well. Proc. Am. Soc. Civ. Eng. J. Hydraul. Div. V. 93, 93–98.
}
