% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/be_rahi.R
\name{be_rahi}
\alias{be_rahi}
\title{be_rahi ## need to check for correctness}
\usage{
be_rahi(dat, dep = "wl", ind = "baro", lag_space = 1,
  inverse = TRUE)
}
\arguments{
\item{dat}{data that has the independent and dependent variables (data.table)}

\item{dep}{name of the dependent variable column (character).  This is 
typically the name for the column holding your water level data.}

\item{ind}{name of the independent variable column (character).  This is 
typically the name for the column holding your barometric pressure data.}

\item{lag_space}{space between difference calculation in number of observations}

\item{inverse}{whether the barometric relationship is inverse
(TRUE means that when the barometric pressure goes up the measured water
level goes down (vented transducer, depth to water), FALSE means that when 
the barometric pressure goes up so does the measured pressure 
(non-vented transducer)) (logical).}
}
\value{
barometric efficiency using Rahi's method
}
\description{
Rahi 2010 solution for calculating barometric efficiency.
}
\examples{
library(data.table)
datetime <- seq.POSIXt(as.POSIXct("2016-01-01 12:00:00"),
                       as.POSIXct("2016-01-05 12:00:00"), by='hour' )
baro <- sin(seq(0, 2 * pi, length.out = length(datetime)))
noise <- rnorm(length(datetime), sd = 0.01)
wl <- -0.4 * baro + noise
dat <- data.table(baro, wl, datetime)
be_rahi(dat, dep = 'wl', ind = 'baro', lag_space = 1)

}
\references{
Rahi, K. A. (2010). Estimating the hydraulic parameters of the 
Arbuckle-Simpson aquifer by analysis of naturally-induced stresses 
(Doctoral dissertation, Oklahoma State University).
}
