% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/be_ratio.R
\name{be_ratio}
\alias{be_ratio}
\title{be_ratio}
\usage{
be_ratio(dat, dep = "wl", ind = "baro", lag_space = 1,
  inverse = TRUE, quant = 0.9, stat = mean, ...)
}
\arguments{
\item{dat}{data that has the independent and dependent variables (data.table)}

\item{dep}{name of the dependent variable column (character).  This is 
typically the name for the column holding your water level data.}

\item{ind}{name of the independent variable column (character).  This is 
typically the name for the column holding your barometric pressure data.}

\item{lag_space}{space between difference calculation in number of observations}

\item{inverse}{whether the barometric relationship is inverse
(TRUE means that when the barometric pressure goes up the measured water
level goes down (vented transducer, depth to water), FALSE means that when 
the barometric pressure goes up so does the measured pressure 
(non-vented transducer)) (logical).}

\item{quant}{quantile cutoff value that differences need to be this large (numeric)}

\item{stat}{the result to return (mean, median, quantile) (function)}

\item{...}{other arguments to pass to "stat"}
}
\value{
barometric efficiency calculated by using ratio method
}
\description{
Calculate the barometric efficiency using the mean (or other statistic) 
of the water level change divided by the barometric pressure change .  
There is the option to only include responses that are large.
}
\examples{
library(data.table)
datetime <- seq.POSIXt(as.POSIXct("2016-01-01 12:00:00"),
                       as.POSIXct("2016-01-05 12:00:00"), by='hour' )
baro <- sin(seq(0, 2*pi, length.out = length(datetime)))
noise <- rnorm(length(datetime), sd = 0.01)
wl <- -0.4 * baro + noise
dat <- data.table(baro, wl, datetime)
be_ratio(dat, quant = 0.5, stat=median)
be_ratio(dat, quant = 0.9, stat=mean)

}
